#############################
 Mail Activity Mail Template
#############################

..
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! This file is generated by oca-gen-addon-readme !!
   !! changes will be overwritten.                   !!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! source digest: sha256:fa88a5911e9d75e4ccaee78931e61a91ccfe34e0de09254e0edd30ad0752f428
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

.. |badge1| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
   :alt: Beta
   :target: https://odoo-community.org/page/development-status

.. |badge2| image:: https://img.shields.io/badge/licence-AGPL--3-blue.png
   :alt: License: AGPL-3
   :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html

|badge1| |badge2|

This module allows to apply an email template to the note field (`note`)
of activities (`mail.activity`) based on the selected activity type
(`mail.activity.type`). This makes it easier to create activities with
predefined notes that can be configured for each activity type.

**Table of contents**

.. contents::
   :local:

***************
 Configuration
***************

No configuration needed for this module.

*******
 Usage
*******

#. Create or edit a mail activity type (`mail.activity.type`) and assign
   it an email template (`mail.template`) on their field
   `mail_template_ids`.

#. Create or edit an activity (`mail.activity`) from the user interface.

#. When you select the activity type, the note field (`note`) will
   automatically be updated with the content of the associated email
   template.

Mail templates are associated to one model, so you have two possibilities:
   -  Assign the model `mail.activity` to the activity type so it will
      be shown / available to every activity.

   -  Assign a particular model to the activity type so only mail
      templates related to that particular model will be available for
      that mail activity type.

Note: If you select an activity type that does not have an associated
email template, the note field will not be updated. If you select an
activity type that has more than one associated email template, the note
field will be updated with the first email template found.

************************
 Known issues / Roadmap
************************

There are no issues for the moment.

*************
 Bug Tracker
*************

Bugs are tracked on `GitLab Issues
<https://gitlab.com/somitcoop/erp-research/odoo-helpdesk/-/issues>`_. In
case of trouble, please check there if your issue has already been
reported. If you spotted it first, help us smashing it by providing a
detailed and welcomed feedback.

Do not contact contributors directly about support or help with
technical issues.

*********
 Credits
*********

Authors
=======

-  SomIT SCCL
-  Som Connexio SCCL

Contributors
============

-  `SomIT SCCL <https://somit.coop>`_:

      -  Álvaro García <alvaro.garcia@somit.coop>
      -  José Robles <jose.robles@somit.coop>

-  `Som Connexio SCCL <https://somconnexio.coop>`_:

      -  Gerard Funosas <gerard.funosas@somconnexio.coop>

Maintainers
===========

This module is maintained by the OCA.

.. image:: https://odoo-community.org/logo.png
   :alt: Odoo Community Association
   :target: https://odoo-community.org

OCA, or the Odoo Community Association, is a nonprofit organization
whose mission is to support the collaborative development of Odoo
features and promote its widespread use.

You are welcome to contribute. To learn how please visit
https://odoo-community.org/page/Contribute.
